@@ -71,13 +71,14 @@ QVariant ActivityListModel::data(const QModelIndex &index, int role) const
                 return QVariant(list.at(0));
             }
             // File does not exist anymore? Let's try to open its path
-            list = FolderMan::instance()->findFileInLocalFolders(QFileInfo(relPath).path(), ast->account());
-            if (list.count() > 0) {
-                return QVariant(list.at(0));
+            if(QFileInfo(relPath).exists()) {
+                list = FolderMan::instance()->findFileInLocalFolders(QFileInfo(relPath).path(), ast->account());
+                if (list.count() > 0) {
+                    return QVariant(list.at(0));
+                }
             }
         }
         return QVariant();
-        break;
      case ActivityItemDelegate::ActionsLinksRole:{
         QList<QVariant> customList;
         foreach (ActivityLink customItem, a._links) {
@@ -86,60 +87,61 @@ QVariant ActivityListModel::data(const QModelIndex &index, int role) const
             customList << customVariant;
         }
         return customList;
-        break;
     }
-    case ActivityItemDelegate::ActionIconRole:
+    case ActivityItemDelegate::ActionIconRole:{
+        ActionIcon actionIcon;
         if(a._type == Activity::NotificationType){
            QIcon cachedIcon = ServerNotificationHandler::iconCache.value(a._id);
-           if(!cachedIcon.isNull())
-               return cachedIcon;
-           else return QIcon(QLatin1String(":/client/resources/bell.svg"));
+            if(!cachedIcon.isNull()) {
+               actionIcon.iconType = ActivityIconType::iconUseCached;
+               actionIcon.cachedIcon = cachedIcon;
+            } else {
+                actionIcon.iconType = ActivityIconType::iconBell;
+            }
         } else if(a._type == Activity::SyncResultType){
-            return QIcon(QLatin1String(":/client/resources/state-error.svg"));
+            actionIcon.iconType = ActivityIconType::iconStateError;
         } else if(a._type == Activity::SyncFileItemType){
                if(a._status == SyncFileItem::NormalError
                    || a._status == SyncFileItem::FatalError
                    || a._status == SyncFileItem::DetailError
                    || a._status == SyncFileItem::BlacklistedError) {
-                   return QIcon(QLatin1String(":/client/resources/state-error.svg"));
+                   actionIcon.iconType = ActivityIconType::iconStateError;
                } else if(a._status == SyncFileItem::SoftError
-                         || a._status == SyncFileItem::FileIgnored
                          || a._status == SyncFileItem::Conflict
                          || a._status == SyncFileItem::Restoration
                          || a._status == SyncFileItem::FileLocked){
-                   return QIcon(QLatin1String(":/client/resources/state-warning.svg"));
+                   actionIcon.iconType = ActivityIconType::iconStateWarning;
+               } else if(a._status == SyncFileItem::FileIgnored){
+                   actionIcon.iconType = ActivityIconType::iconStateInfo;
+               } else {
+                   actionIcon.iconType = ActivityIconType::iconStateSync;
                }
-               return QIcon(QLatin1String(":/client/resources/state-sync.svg"));
+        } else {
+            actionIcon.iconType = ActivityIconType::iconActivity;
         }
-        return QIcon(QLatin1String(":/client/resources/activity.png"));
-        break;
+        QVariant icn;
+        icn.setValue(actionIcon);
+        return icn;
+    }
     case ActivityItemDelegate::ObjectTypeRole:
         return a._objectType;
-        break;
     case ActivityItemDelegate::ActionRole:{
         QVariant type;
         type.setValue(a._type);
         return type;
-        break;
     }
     case ActivityItemDelegate::ActionTextRole:
         return a._subject;
-        break;
     case ActivityItemDelegate::MessageRole:
         return a._message;
-        break;
     case ActivityItemDelegate::LinkRole:
         return a._link;
-        break;
     case ActivityItemDelegate::AccountRole:
         return a._accName;
-        break;
     case ActivityItemDelegate::PointInTimeRole:
-        return Utility::timeAgoInWords(a._dateTime);
-        break;
+        return QString("%1 (%2)").arg(a._dateTime.toLocalTime().toString(Qt::DefaultLocaleShortDate), Utility::timeAgoInWords(a._dateTime.toLocalTime()));
     case ActivityItemDelegate::AccountConnectedRole:
         return (ast && ast->isConnected());
-        break;
     default:
         return QVariant();
     }
@@ -228,6 +230,29 @@ void ActivityListModel::addErrorToActivityList(Activity activity) {
     combineActivityLists();
 }
 
+void ActivityListModel::addIgnoredFileToList(Activity newActivity) {
+    qCInfo(lcActivity) << "First checking for duplicates then add file to the notification list of ignored files: " << newActivity._file;
+
+    bool duplicate = false;
+    if(_listOfIgnoredFiles.size() == 0){
+        _notificationIgnoredFiles = newActivity;
+        _notificationIgnoredFiles._subject = tr("Files from the ignore list as well as symbolic links are not synced. This includes:");
+        _listOfIgnoredFiles.append(newActivity);
+        return;
+    }
+
+    foreach(Activity activity, _listOfIgnoredFiles){
+        if(activity._file == newActivity._file){
+            duplicate = true;
+            break;
+        }
+    }
+
+    if(!duplicate){
+        _notificationIgnoredFiles._message.append(", " + newActivity._file);
+    }
+}
+
 void ActivityListModel::addNotificationToActivityList(Activity activity) {
     qCInfo(lcActivity) << "Notification successfully added to the notification list: " << activity._subject;
     _notificationLists.prepend(activity);
@@ -241,7 +266,7 @@ void ActivityListModel::clearNotifications() {
 }
 
 void ActivityListModel::removeActivityFromActivityList(int row) {
-    Activity activity =  _finalList.at(row);
+    Activity activity = _finalList.at(row);
     removeActivityFromActivityList(activity);
     combineActivityLists();
 }
@@ -275,22 +300,31 @@ void ActivityListModel::removeActivityFromActivityList(Activity activity) {
     }
 }
 
-
 void ActivityListModel::combineActivityLists()
 {
     ActivityList resultList;
 
-    std::sort(_notificationErrorsLists.begin(), _notificationErrorsLists.end());
-    resultList.append(_notificationErrorsLists);
+    if(_notificationErrorsLists.count() > 0) {
+        std::sort(_notificationErrorsLists.begin(), _notificationErrorsLists.end());
+        resultList.append(_notificationErrorsLists);
+    }
+    if(_listOfIgnoredFiles.size() > 0)
+        resultList.append(_notificationIgnoredFiles);
 
-    std::sort(_notificationLists.begin(), _notificationLists.end());
-    resultList.append(_notificationLists);
+    if(_notificationLists.count() > 0) {
+        std::sort(_notificationLists.begin(), _notificationLists.end());
+        resultList.append(_notificationLists);
+    }
 
-    std::sort(_syncFileItemLists.begin(), _syncFileItemLists.end());
-    resultList.append(_syncFileItemLists);
+    if(_syncFileItemLists.count() > 0) {
+        std::sort(_syncFileItemLists.begin(), _syncFileItemLists.end());
+        resultList.append(_syncFileItemLists);
+    }
 
-    std::sort(_activityLists.begin(), _activityLists.end());
-    resultList.append(_activityLists);
+    if(_activityLists.count() > 0) {
+        std::sort(_activityLists.begin(), _activityLists.end());
+        resultList.append(_activityLists);
+    }
 
     beginResetModel();
     _finalList.clear();
