@@ -72,7 +72,8 @@ namespace {
         "                         (to be used with --logdir)\n"
         "  --logflush           : flush the log file after every write.\n"
         "  --logdebug           : also output debug-level messages in the log.\n"
-        "  --confdir <dirname>  : Use the given configuration folder.\n";
+        "  --confdir <dirname>  : Use the given configuration folder.\n"
+        "  --background         : launch the application in the background.\n";
 
     QString applicationTrPath()
     {
@@ -106,6 +107,8 @@ Application::Application(int &argc, char **argv)
     , _logDebug(false)
     , _userTriggeredConnect(false)
     , _debugMode(false)
+    , _backgroundMode(false)
+    , _isQuitting(false)
 {
     _startedAt.start();
 
@@ -251,6 +254,9 @@ Application::Application(int &argc, char **argv)
 
     // Cleanup at Quit.
     connect(this, &QCoreApplication::aboutToQuit, this, &Application::slotCleanup);
+
+    // Allow other classes to hook into isShowingSettingsDialog() signals (re-auth widgets, for example)
+    connect(_gui.data(), &ownCloudGui::isShowingSettingsDialog, this, &Application::slotGuiIsShowingSettings);
 }
 
 Application::~Application()
@@ -262,6 +268,8 @@ Application::~Application()
     }
 
     // Remove the account from the account manager so it can be deleted.
+    disconnect(AccountManager::instance(), &AccountManager::accountRemoved,
+        this, &Application::slotAccountStateRemoved);
     AccountManager::instance()->shutdown();
 }
 
@@ -281,7 +289,7 @@ void Application::slotAccountStateRemoved(AccountState *accountState)
     }
 
     // if there is no more account, show the wizard.
-    if (AccountManager::instance()->accounts().isEmpty()) {
+    if (!_isQuitting && AccountManager::instance()->accounts().isEmpty()) {
         // allow to add a new account if there is non any more. Always think
         // about single account theming!
         OwncloudSetupWizard::runWizard(this, SLOT(slotownCloudWizardDone(int)));
@@ -304,6 +312,8 @@ void Application::slotAccountStateAdded(AccountState *accountState)
 
 void Application::slotCleanup()
 {
+    _isQuitting = true;
+
     AccountManager::instance()->save();
     FolderMan::instance()->unloadAndDeleteAllFolders();
 
@@ -467,6 +477,8 @@ void Application::parseOptions(const QStringList &options)
         } else if (option == QLatin1String("--debug")) {
             _logDebug = true;
             _debugMode = true;
+        } else if (option == QLatin1String("--background")) {
+            _backgroundMode = true;
         } else if (option == QLatin1String("--version")) {
             _versionOnly = true;
         } else {
@@ -540,6 +552,11 @@ bool Application::debugMode()
     return _debugMode;
 }
 
+bool Application::backgroundMode() const
+{
+    return _backgroundMode;
+}
+
 void Application::setHelp()
 {
     _helpOnly = true;
@@ -634,5 +651,9 @@ void Application::showSettingsDialog()
     _gui->slotShowSettings();
 }
 
+void Application::slotGuiIsShowingSettings()
+{
+    emit isShowingSettingsDialog();
+}
 
 } // namespace OCC
