@@ -63,6 +63,7 @@ public:
     void showHelp();
     void showHint(std::string errorHint);
     bool debugMode();
+    bool backgroundMode() const;
     bool versionOnly(); // only display the version?
     void showVersion();
 
@@ -81,6 +82,7 @@ protected:
 signals:
     void folderRemoved();
     void folderStateChanged(Folder *);
+    void isShowingSettingsDialog();
 
 protected slots:
     void slotParseMessage(const QString &, QObject *);
@@ -90,6 +92,7 @@ protected slots:
     void slotAccountStateAdded(AccountState *accountState);
     void slotAccountStateRemoved(AccountState *accountState);
     void slotSystemOnlineConfigurationChanged(QNetworkConfiguration);
+    void slotGuiIsShowingSettings();
 
 private:
     void setHelp();
@@ -112,6 +115,8 @@ private:
     bool _logDebug;
     bool _userTriggeredConnect;
     bool _debugMode;
+    bool _backgroundMode;
+    bool _isQuitting;
 
     ClientProxy _proxy;
 
