@@ -351,6 +351,10 @@ void Folder::showSyncResultPopup()
         createGuiLog(_syncResult.firstItemError()->_file, LogStatusError, errorCount);
     }
 
+    if (int lockedCount = _syncResult.numLockedItems()) {
+        createGuiLog(_syncResult.firstItemLocked()->_file, LogStatusFileLocked, lockedCount);
+    }
+
     qCInfo(lcFolder) << "Folder sync result: " << int(_syncResult.status());
 }
 
@@ -413,6 +417,13 @@ void Folder::createGuiLog(const QString &filename, LogStatus status, int count,
                 text = tr("%1 could not be synced due to an error. See the log for details.").arg(file);
             }
             break;
+        case LogStatusFileLocked:
+            if (count > 1) {
+                text = tr("%1 and %n other file(s) are currently locked.", "", count -1).arg(file);
+            } else {
+                text = tr("%1 is currently locked.").arg(file);
+            }
+            break;
         }
 
         if (!text.isEmpty()) {
@@ -891,13 +902,19 @@ void Folder::slotItemCompleted(const SyncFileItemPtr &item)
     }
 
     // add new directories or remove gone away dirs to the watcher
-    if (item->isDirectory() && item->_instruction == CSYNC_INSTRUCTION_NEW) {
-        if (_folderWatcher)
-            _folderWatcher->addPath(path() + item->_file);
-    }
-    if (item->isDirectory() && item->_instruction == CSYNC_INSTRUCTION_REMOVE) {
-        if (_folderWatcher)
-            _folderWatcher->removePath(path() + item->_file);
+    if (_folderWatcher && item->isDirectory()) {
+	switch (item->_instruction) {
+	    case CSYNC_INSTRUCTION_NEW:
+                _folderWatcher->addPath(path() + item->_file);
+	    break;
+	    case CSYNC_INSTRUCTION_REMOVE:
+                _folderWatcher->removePath(path() + item->_file);
+	    break;
+	    case CSYNC_INSTRUCTION_RENAME:
+                _folderWatcher->removePath(path() + item->_file);
+                _folderWatcher->addPath(path() + item->destination());
+	    break;
+	}
     }
 
     // Success and failure of sync items adjust what the next sync is
@@ -1068,20 +1085,20 @@ void Folder::slotAboutToRemoveAllFiles(SyncFileItem::Direction dir, bool *cancel
     if (!cfgFile.promptDeleteFiles())
         return;
 
-    QString msg = dir == SyncFileItem::Down ? tr("All files in the sync folder '%1' folder were deleted on the server.\n"
+    QString msg = dir == SyncFileItem::Down ? tr("All files in the sync folder '%1' were deleted on the server.\n"
                                                  "These deletes will be synchronized to your local sync folder, making such files "
                                                  "unavailable unless you have a right to restore. \n"
-                                                 "If you decide to keep the files, they will be re-synced with the server if you have rights to do so.\n"
+                                                 "If you decide to restore the files, they will be re-synced with the server if you have rights to do so.\n"
                                                  "If you decide to delete the files, they will be unavailable to you, unless you are the owner.")
-                                            : tr("All the files in your local sync folder '%1' were deleted. These deletes will be "
-                                                 "synchronized with your server, making such files unavailable unless restored.\n"
-                                                 "Are you sure you want to sync those actions with the server?\n"
-                                                 "If this was an accident and you decide to keep your files, they will be re-synced from the server.");
-    QMessageBox msgBox(QMessageBox::Warning, tr("Download new files?"),
+                                            : tr("All files got deleted from your local sync folder '%1'.\n"
+                                                 "These files will be deleted from the server and will not be available on your other devices if they "
+                                                 "will not be restored.\n"
+                                                 "If this action was unintended you can restore the lost data now.");
+    QMessageBox msgBox(QMessageBox::Warning, tr("Delete all files?"),
         msg.arg(shortGuiLocalPath()));
     msgBox.setWindowFlags(msgBox.windowFlags() | Qt::WindowStaysOnTopHint);
-    msgBox.addButton(tr("Download new files"), QMessageBox::DestructiveRole);
-    QPushButton *keepBtn = msgBox.addButton(tr("Keep local files"), QMessageBox::AcceptRole);
+    msgBox.addButton(tr("Delete all files"), QMessageBox::DestructiveRole);
+    QPushButton *keepBtn = msgBox.addButton(tr("Restore deleted files"), QMessageBox::AcceptRole);
     if (msgBox.exec() == -1) {
         *cancel = true;
         return;
