@@ -331,7 +331,7 @@ void OwncloudSetupWizard::slotConnectToOCUrl(const QString &url)
     AbstractCredentials *creds = _ocWizard->getCredentials();
     _ocWizard->account()->setCredentials(creds);
     _ocWizard->setField(QLatin1String("OCUrl"), url);
-    _ocWizard->appendToConfigurationLog(tr("Trying to connect to %1 at %2...")
+    _ocWizard->appendToConfigurationLog(tr("Trying to connect to %1 at %2 …")
                                             .arg(Theme::instance()->appNameGUI())
                                             .arg(url));
 
@@ -407,8 +407,9 @@ void OwncloudSetupWizard::slotAuthError()
         errorMsg = tr("There was an invalid response to an authenticated webdav request");
     }
 
-    _ocWizard->show();
-    if (_ocWizard->currentId() == WizardCommon::Page_ShibbolethCreds || _ocWizard->currentId() == WizardCommon::Page_OAuthCreds) {
+    // bring wizard to top
+    _ocWizard->bringToTop();
+    if (_ocWizard->currentId() == WizardCommon::Page_ShibbolethCreds || _ocWizard->currentId() == WizardCommon::Page_OAuthCreds || _ocWizard->currentId() == WizardCommon::Page_Flow2AuthCreds) {
         _ocWizard->back();
     }
     _ocWizard->displayError(errorMsg, _ocWizard->currentId() == WizardCommon::Page_ServerSetup && checkDowngradeAdvised(reply));
@@ -452,7 +453,7 @@ void OwncloudSetupWizard::slotCreateLocalAndRemoteFolders(const QString &localFo
             tr("Local sync folder %1 already exists, setting it up for sync.<br/><br/>")
                 .arg(Utility::escape(localFolder)));
     } else {
-        QString res = tr("Creating local sync folder %1...").arg(localFolder);
+        QString res = tr("Creating local sync folder %1 …").arg(localFolder);
         if (fi.mkpath(localFolder)) {
             FileSystem::setFolderMinimumPermissions(localFolder);
             Utility::setupFavLink(localFolder);
@@ -466,7 +467,41 @@ void OwncloudSetupWizard::slotCreateLocalAndRemoteFolders(const QString &localFo
         _ocWizard->appendToConfigurationLog(res);
     }
     if (nextStep) {
-        EntityExistsJob *job = new EntityExistsJob(_ocWizard->account(), _ocWizard->account()->davPath() + remoteFolder, this);
+        /*
+         * BEGIN - Sanitize URL paths to eliminate double-slashes
+         *
+         *         Purpose: Don't rely on unsafe paths, be extra careful.
+         *
+         *         Example: https://cloud.example.com/remote.php/webdav//
+         *
+        */
+        qCInfo(lcWizard) << "Sanitize got URL path:" << QString(_ocWizard->account()->url().toString() + '/' + _ocWizard->account()->davPath() + remoteFolder);
+
+        QString newDavPath = _ocWizard->account()->davPath(),
+                newRemoteFolder = remoteFolder;
+
+        while (newDavPath.startsWith('/')) {
+            newDavPath.remove(0, 1);
+        }
+        while (newDavPath.endsWith('/')) {
+            newDavPath.chop(1);
+        }
+
+        while (newRemoteFolder.startsWith('/')) {
+            newRemoteFolder.remove(0, 1);
+        }
+        while (newRemoteFolder.endsWith('/')) {
+            newRemoteFolder.chop(1);
+        }
+
+        QString newUrlPath = newDavPath + '/' + newRemoteFolder;
+
+        qCInfo(lcWizard) << "Sanitized to URL path:" << _ocWizard->account()->url().toString() + '/' + newUrlPath;
+        /*
+         * END - Sanitize URL paths to eliminate double-slashes
+        */
+
+        EntityExistsJob *job = new EntityExistsJob(_ocWizard->account(), newUrlPath, this);
         connect(job, &EntityExistsJob::exists, this, &OwncloudSetupWizard::slotRemoteFolderExists);
         job->start();
     } else {
