@@ -19,6 +19,7 @@
 #include "capabilities.h"
 #include "guiutility.h"
 #include "sharemanager.h"
+#include "theme.h"
 
 #include "QProgressIndicator.h"
 #include <QBuffer>
@@ -240,6 +241,8 @@ void ShareLinkWidget::setupUiOptions(){
 
     //TO DO
     //startAnimation(0, height());
+
+    customizeStyle();
 }
 
 void ShareLinkWidget::slotCopyLinkShare(bool clicked){
@@ -277,6 +280,7 @@ void ShareLinkWidget::slotCreatePassword()
 
 void ShareLinkWidget::slotCreateShareLink(bool clicked)
 {
+    Q_UNUSED(clicked);
     slotToggleAnimation(true);
     emit createLinkShare();
 }
@@ -488,4 +492,32 @@ void ShareLinkWidget::displayError(const QString &errMsg)
     _ui->errorLabel->setText(errMsg);
     _ui->errorLabel->show();
 }
+
+void ShareLinkWidget::slotStyleChanged()
+{
+    customizeStyle();
+}
+
+void ShareLinkWidget::customizeStyle()
+{
+    _unshareLinkAction->setIcon(Theme::createColorAwareIcon(":/client/resources/delete.png"));
+
+    _addAnotherLinkAction->setIcon(Theme::createColorAwareIcon(":/client/resources/add.png"));
+
+    _ui->enableShareLink->setIcon(Theme::createColorAwareIcon(":/client/resources/copy.svg"));
+
+// only on master, not in stable-2.6 yet
+//    _ui->shareLinkIconLabel->setPixmap(Theme::createColorAwarePixmap(":/client/resources/public.svg"));
+    _ui->createShareButton->setIcon(Theme::createColorAwareIcon(":/client/resources/public.svg"));
+
+    _ui->shareLinkToolButton->setIcon(Theme::createColorAwareIcon(":/client/resources/more.svg"));
+
+// only on master, not in stable-2.6 yet
+//    _ui->confirmNote->setIcon(Theme::createColorAwareIcon(":/client/resources/confirm.svg"));
+    _ui->confirmPassword->setIcon(Theme::createColorAwareIcon(":/client/resources/confirm.svg"));
+    _ui->confirmExpirationDate->setIcon(Theme::createColorAwareIcon(":/client/resources/confirm.svg"));
+
+    _ui->progressIndicator->setColor(QGuiApplication::palette().color(QPalette::Text));
+}
+
 }
