@@ -26,6 +26,7 @@
 #include "thumbnailjob.h"
 #include "sharee.h"
 #include "sharemanager.h"
+#include "theme.h"
 
 #include "QProgressIndicator.h"
 #include <QBuffer>
@@ -112,6 +113,8 @@ ShareUserGroupWidget::ShareUserGroupWidget(AccountPtr account,
     //_ui->shareeHorizontalLayout->addWidget(&_pi_sharee);
 
     _parentScrollArea = parentWidget()->findChild<QScrollArea*>("scrollArea");
+
+    customizeStyle();
 }
 
 ShareUserGroupWidget::~ShareUserGroupWidget()
@@ -211,8 +214,11 @@ void ShareUserGroupWidget::slotSharesFetched(const QList<QSharedPointer<Share>>
         connect(s, &ShareUserLine::resizeRequested, this, &ShareUserGroupWidget::slotAdjustScrollWidgetSize);
         connect(s, &ShareUserLine::visualDeletionDone, this, &ShareUserGroupWidget::getShares);
         s->setBackgroundRole(layout->count() % 2 == 0 ? QPalette::Base : QPalette::AlternateBase);
+
+        // Connect styleChanged events to our widget, so it can adapt (Dark-/Light-Mode switching)
+        connect(this, &ShareUserGroupWidget::styleChanged, s, &ShareUserLine::slotStyleChanged);
+
         layout->addWidget(s);
-        s->setVisible(true);
 
         x++;
         if (x <= 3) {
@@ -256,7 +262,8 @@ void ShareUserGroupWidget::slotPrivateLinkShare()
     auto menu = new QMenu(this);
     menu->setAttribute(Qt::WA_DeleteOnClose);
 
-    menu->addAction(QIcon(":/client/resources/copy.svg"),
+    // this icon is not handled by slotStyleChanged() -> customizeStyle but we can live with that
+    menu->addAction(Theme::createColorAwareIcon(":/client/resources/copy.svg"),
                     tr("Copy link"),
         this, SLOT(slotPrivateLinkCopy()));
 
@@ -359,6 +366,25 @@ void ShareUserGroupWidget::slotPrivateLinkEmail()
         this);
 }
 
+void ShareUserGroupWidget::slotStyleChanged()
+{
+    customizeStyle();
+
+    // Notify the other widgets (ShareUserLine in this case, Dark-/Light-Mode switching)
+    emit styleChanged();
+}
+
+void ShareUserGroupWidget::customizeStyle()
+{
+    _ui->confirmShare->setIcon(Theme::createColorAwareIcon(":/client/resources/confirm.svg"));
+
+    _pi_sharee.setColor(QGuiApplication::palette().color(QPalette::Text));
+
+    foreach (auto pi, _parentScrollArea->findChildren<QProgressIndicator *>()) {
+        pi->setColor(QGuiApplication::palette().color(QPalette::Text));;
+    }
+}
+
 ShareUserLine::ShareUserLine(QSharedPointer<Share> share,
     SharePermissions maxSharingPermissions,
     bool isFile,
@@ -389,6 +415,15 @@ ShareUserLine::ShareUserLine(QSharedPointer<Share> share,
     menu->addAction(_permissionReshare);
     connect(_permissionReshare, &QAction::triggered, this, &ShareUserLine::slotPermissionsChanged);
 
+    menu->addSeparator();
+
+      // Adds action to delete share widget
+      QIcon deleteicon = QIcon::fromTheme(QLatin1String("user-trash"),QIcon(QLatin1String(":/client/resources/delete.png")));
+      _deleteShareButton= new QAction(deleteicon,tr("Unshare"), this);
+
+    menu->addAction(_deleteShareButton);
+    connect(_deleteShareButton, &QAction::triggered, this, &ShareUserLine::on_deleteShareButton_clicked);
+
     /*
      * Files can't have create or delete permissions
      */
@@ -415,8 +450,9 @@ ShareUserLine::ShareUserLine(QSharedPointer<Share> share,
     _ui->permissionToolButton->setMenu(menu);
     _ui->permissionToolButton->setPopupMode(QToolButton::InstantPopup);
 
-    QIcon icon(QLatin1String(":/client/resources/more.svg"));
-    _ui->permissionToolButton->setIcon(icon);
+    // icon now set in: customizeStyle
+    /*QIcon icon(QLatin1String(":/client/resources/more.svg"));
+    _ui->permissionToolButton->setIcon(icon);*/
 
     // Set the permissions checkboxes
     displayPermissions();
@@ -435,21 +471,16 @@ ShareUserLine::ShareUserLine(QSharedPointer<Share> share,
     connect(share.data(), &Share::permissionsSet, this, &ShareUserLine::slotPermissionsSet);
     connect(share.data(), &Share::shareDeleted, this, &ShareUserLine::slotShareDeleted);
 
-    _ui->deleteShareButton->setIcon(QIcon::fromTheme(QLatin1String("user-trash"),
-                                                     QIcon(QLatin1String(":/client/resources/delete.png"))));
+    // _ui->deleteShareButton->setIcon(QIcon::fromTheme(QLatin1String("user-trash"),
+    //                                                  QIcon(QLatin1String(":/client/resources/delete.png"))));
 
     if (!share->account()->capabilities().shareResharing()) {
         _permissionReshare->setVisible(false);
     }
 
-    //If the initiator is not you. And the recipient is not you. Show it without any options.
-    if(share->account()->id() != share->getId() && share->account()->davUser() != share->getShareWith()->shareWith()){
-        _ui->permissionsEdit->hide();
-        _ui->permissionToolButton->hide();
-        _ui->deleteShareButton->hide();
-    }
-
     loadAvatar();
+
+    customizeStyle();
 }
 
 void ShareUserLine::loadAvatar()
@@ -644,4 +675,18 @@ void ShareUserLine::displayPermissions()
         _permissionDelete->setChecked(perm & SharePermissionDelete);
     }
 }
+
+void ShareUserLine::slotStyleChanged()
+{
+    customizeStyle();
+}
+
+void ShareUserLine::customizeStyle()
+{
+    _ui->permissionToolButton->setIcon(Theme::createColorAwareIcon(":/client/resources/more.svg"));
+
+    QIcon deleteicon = QIcon::fromTheme(QLatin1String("user-trash"),Theme::createColorAwareIcon(QLatin1String(":/client/resources/delete.png")));
+    _deleteShareButton->setIcon(deleteicon);
+}
+
 }
