@@ -33,29 +33,4 @@ NextcloudTheme::NextcloudTheme()
 {
 }
 
-#ifndef TOKEN_AUTH_ONLY
-QVariant NextcloudTheme::customMedia(CustomMediaType)
-{
-    return QVariant();
-}
-#endif
-
-#ifndef TOKEN_AUTH_ONLY
-QColor NextcloudTheme::wizardHeaderBackgroundColor() const
-{
-    return QColor("#0082c9");
-}
-
-QColor NextcloudTheme::wizardHeaderTitleColor() const
-{
-    return QColor("#ffffff");
-}
-
-QPixmap NextcloudTheme::wizardHeaderLogo() const
-{
-    return QPixmap(hidpiFileName(":/client/theme/colored/wizard_logo.png"));
-}
-
-#endif
-
 }
