@@ -28,6 +28,7 @@ SyncResult::SyncResult()
     , _numNewConflictItems(0)
     , _numOldConflictItems(0)
     , _numErrorItems(0)
+    , _numLockedItems(0)
 
 {
 }
@@ -139,6 +140,13 @@ void SyncResult::processCompletedItem(const SyncFileItemPtr &item)
         _folderStructureWasChanged = true;
     }
 
+    if(item->_status == SyncFileItem::FileLocked){
+        _numLockedItems++;
+        if (!_firstItemLocked) {
+            _firstItemLocked = item;
+        }
+    }
+
     // Process the item to the gui
     if (item->_status == SyncFileItem::FatalError || item->_status == SyncFileItem::NormalError) {
         //: this displays an error string (%2) for a file %1
